@@ -21,10 +21,11 @@
 #include <spawn.h>
 
 #if !(defined(HAVE_WORKING_VFORK) || defined(S_SPLINT_S))
-  #define vfork fork
+#define vfork fork
 #endif
 
-int main(int argc, char *argv[]) {
+int main(int argc, char *argv[])
+{
 	static const int yes = 1;
 	char *s;
 	struct sockaddr_in server;
@@ -32,45 +33,48 @@ int main(int argc, char *argv[]) {
 	int sock_listen, sock_accept;
 	pid_t pid;
 
-	if(argc < 3) {
+	if (argc < 3) {
 		fprintf(stderr, "usage: %s [ipaddr:]port program "
-				"[argv0 argv1 ...]\n", argv[0]);
+			"[argv0 argv1 ...]\n", argv[0]);
 		return 1;
 	}
-	
+
 	memset(&server, 0, sizeof(server));
 	server.sin_family = AF_INET;
 	assert(argv[1] != NULL);
 	s = strchr(argv[1], ':');
-	if(NULL == s)
+	if (NULL == s)
 		s = argv[1];
 	else {
 		*s++ = '\0';
-		if(0 == inet_aton(argv[1], &server.sin_addr)) {
-			fprintf(stderr, "not an ip address: %s\n", argv[1]);
+		if (0 == inet_aton(argv[1], &server.sin_addr)) {
+			fprintf(stderr, "not an ip address: %s\n",
+				argv[1]);
 			return 1;
 		}
 	}
-	if((1 != sscanf(s, "%u", &port)) ||
-			port != (unsigned int)(uint16_t)port) {
+	if ((1 != sscanf(s, "%u", &port)) ||
+	    port != (unsigned int) (uint16_t) port) {
 		fprintf(stderr, "not a valid port: %s\n", s);
 		return 1;
 	}
 	server.sin_port = htons(port);
-	if((sock_listen = socket(AF_INET, SOCK_STREAM, 0)) < 0) {
+	if ((sock_listen = socket(AF_INET, SOCK_STREAM, 0)) < 0) {
 		perror("socket creation failed");
 		return 1;
 	}
-	if(setsockopt(sock_listen, SOL_SOCKET, SO_REUSEADDR, &yes, sizeof(yes))
-			== -1) { 
+	if (setsockopt
+	    (sock_listen, SOL_SOCKET, SO_REUSEADDR, &yes, sizeof(yes))
+	    == -1) {
 		perror("failed to set SO_REUSEADDR on socket");
 	}
-	if(bind(sock_listen, (struct sockaddr*)&server, sizeof(server)) < 0) {
+	if (bind(sock_listen, (struct sockaddr *) &server, sizeof(server))
+	    < 0) {
 		perror("failed to bind socket");
 		close(sock_listen);
 		return 1;
 	}
-	if(listen(sock_listen, 5) != 0) {
+	if (listen(sock_listen, 5) != 0) {
 		perror("failed to listen on the socket");
 		close(sock_listen);
 		return 1;
@@ -79,7 +83,7 @@ int main(int argc, char *argv[]) {
 	/* We do *not* care about childs */
 	signal(SIGCHLD, SIG_IGN);
 
-	while((sock_accept = accept(sock_listen, NULL, NULL)) != -1) {
+	while ((sock_accept = accept(sock_listen, NULL, NULL)) != -1) {
 		posix_spawn_file_actions_t action;
 
 		posix_spawn_file_actions_init(&action);
@@ -88,18 +92,16 @@ int main(int argc, char *argv[]) {
 		posix_spawn_file_actions_adddup2(&action, sock_accept, 1);
 		posix_spawn_file_actions_addclose(&action, sock_accept);
 
-		if(0 == posix_spawnp(&pid, argv[2],
-			&action,
-			NULL,
-			argv + 3, NULL)) {
+		if (0 == posix_spawnp(&pid, argv[2],
+				      &action, NULL, argv + 3, NULL)) {
 			close(sock_accept);
 		} else {
-			perror("vfork failed");
+			perror("vfork failed in " __FILE__);
 			close(sock_listen);
 			return 1;
 		}
 	}
-	perror("accept failed");
+	perror("accept failed in " __FILE__);
 	close(sock_listen);
 	return 1;
 }
