@@ -14,13 +14,15 @@
 
 extern char **environ;
 
-int writeyes(void) {
+int writeyes(void)
+{
 	puts("yes");
 	return 0;
 }
 
-int autoconf_check_readable(const char *path) {
-	if(0 == access(path, R_OK))
+int autoconf_check_readable(const char *path)
+{
+	if (0 == access(path, R_OK))
 		return writeyes();
 	else {
 		printf("no (%s is not readable, errno=%d)\n", path, errno);
@@ -28,55 +30,63 @@ int autoconf_check_readable(const char *path) {
 	}
 }
 
-int getenvint(const char *name, int defvalue) {
+int getenvint(const char *name, int defvalue)
+{
 	const char *value;
 	value = getenv(name);
-	if(value == NULL)
+	if (value == NULL)
 		return defvalue;
 	return atoi(value);
 }
 
-/*@null@*/ /*@observer@*/ const char *getenv_composed(const char *name1,
-		const char *name2) {
+static
+				    /*@null@ */
+ /*@observer@ */
+const char *getenv_composed(const char *name1, const char *name2)
+{
 	char **p;
 	size_t len1 = strlen(name1), len2 = strlen(name2);
-	for(p = environ; *p; ++p) {
-		if(0 == strncmp(*p, name1, len1) &&
-				0 == strncmp(len1 + *p, name2, len2) &&
-				(*p)[len1 + len2] == '=')
+	for (p = environ; *p; ++p) {
+		if (0 == strncmp(*p, name1, len1) &&
+		    0 == strncmp(len1 + *p, name2, len2) &&
+		    (*p)[len1 + len2] == '=')
 			return len1 + len2 + 1 + *p;
 	}
 	return NULL;
 }
 
-void print_warning(const char *name) {
+void print_warning(const char *name)
+{
 	const char *p;
 	p = getenv_composed(name, "_warning");
-	if(p == NULL)
+	if (p == NULL)
 		p = getenv("warning");
-	if(p == NULL)
+	if (p == NULL)
 		return;
 
 	printf("%s.warning %s\n", name, p);
 }
 
-void print_critical(const char *name) {
+void print_critical(const char *name)
+{
 	const char *p;
 	p = getenv_composed(name, "_critical");
-	if(p == NULL)
+	if (p == NULL)
 		p = getenv("critical");
-	if(p == NULL)
+	if (p == NULL)
 		return;
 
 	printf("%s.critical %s\n", name, p);
 }
 
-void print_warncrit(const char *name) {
+void print_warncrit(const char *name)
+{
 	print_warning(name);
 	print_critical(name);
 }
 
-int fail(const char *message) {
+int fail(const char *message)
+{
 	fputs(message, stderr);
 	fputc('\n', stderr);
 	return 1;
